aboutsummaryrefslogtreecommitdiffstats
path: root/home/text.asm
diff options
context:
space:
mode:
Diffstat (limited to 'home/text.asm')
-rw-r--r--home/text.asm8
1 files changed, 4 insertions, 4 deletions
diff --git a/home/text.asm b/home/text.asm
index 25233e05..d6baf35c 100644
--- a/home/text.asm
+++ b/home/text.asm
@@ -63,7 +63,7 @@ PlaceNextChar::
jr nz, .NotNext
ld bc, 2 * SCREEN_WIDTH
ldh a, [hUILayoutFlags]
- bit 2, a
+ bit BIT_SINGLE_SPACED_LINES, a
jr z, .ok
ld bc, SCREEN_WIDTH
.ok
@@ -117,13 +117,13 @@ NullChar:: ; unused
pop hl
; A "<NULL>" character in a printed string
; displays an error message with the current value
; of hSpriteIndexOrTextID in decimal format.
; This is a debugging leftover.
ld de, TextIDErrorText
dec de
ret
-TextIDErrorText:: ; "[hSpriteIndexOrTextID] ERROR."
+TextIDErrorText:: ; "[hTextID] ERROR."
text_far _TextIDErrorText
text_end
@@ -322,7 +322,7 @@ ProtectedDelay3::
TextCommandProcessor::
ld a, [wLetterPrintingDelayFlags]
push af
- set 1, a
+ set BIT_TEXT_DELAY, a
ld e, a
ldh a, [hClearLetterPrintingDelayFlags]
xor e
@@ -117,13 +117,13 @@ NullChar:: ; unused
; A "<NULL>" character in a printed string
; displays an error message with the current value
- ; of hSpriteIndexOrTextID in decimal format.
+ ; of hTextID in decimal format.
; This is a debugging leftover.
ld de, TextIDErrorText